
__version__ = "0.13rc2"
__version_vcs_info__ = {
    'branch': 'release-0.13',
    'revid': 'bb681d6',
    'revno': 2372}
__version_user_email__ = "saxtouri@admin.grnet.gr"
__version_user_name__ = "Stavros Sachtouris"
